import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleGameServicesGameServerConfigConfig extends cdktf.TerraformMetaArguments {
    /**
    * A unique id for the deployment config.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#config_id GoogleGameServicesGameServerConfig#config_id}
    */
    readonly configId: string;
    /**
    * A unique id for the deployment.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#deployment_id GoogleGameServicesGameServerConfig#deployment_id}
    */
    readonly deploymentId: string;
    /**
    * The description of the game server config.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#description GoogleGameServicesGameServerConfig#description}
    */
    readonly description?: string;
    /**
    * The labels associated with this game server config. Each label is a
  key-value pair.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#labels GoogleGameServicesGameServerConfig#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Location of the Deployment.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#location GoogleGameServicesGameServerConfig#location}
    */
    readonly location?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#project GoogleGameServicesGameServerConfig#project}
    */
    readonly project?: string;
    /**
    * fleet_configs block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#fleet_configs GoogleGameServicesGameServerConfig#fleet_configs}
    */
    readonly fleetConfigs: GoogleGameServicesGameServerConfigFleetConfigs[] | cdktf.IResolvable;
    /**
    * scaling_configs block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#scaling_configs GoogleGameServicesGameServerConfig#scaling_configs}
    */
    readonly scalingConfigs?: GoogleGameServicesGameServerConfigScalingConfigs[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#timeouts GoogleGameServicesGameServerConfig#timeouts}
    */
    readonly timeouts?: GoogleGameServicesGameServerConfigTimeouts;
}
export interface GoogleGameServicesGameServerConfigFleetConfigs {
    /**
    * The fleet spec, which is sent to Agones to configure fleet.
  The spec can be passed as inline json but it is recommended to use a file reference
  instead. File references can contain the json or yaml format of the fleet spec. Eg:
  
  * fleet_spec = jsonencode(yamldecode(file("fleet_configs.yaml")))
  * fleet_spec = file("fleet_configs.json")
  
  The format of the spec can be found :
  'https://agones.dev/site/docs/reference/fleet/'.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#fleet_spec GoogleGameServicesGameServerConfig#fleet_spec}
    */
    readonly fleetSpec: string;
    /**
    * The name of the FleetConfig.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#name GoogleGameServicesGameServerConfig#name}
    */
    readonly name?: string;
}
export declare function googleGameServicesGameServerConfigFleetConfigsToTerraform(struct?: GoogleGameServicesGameServerConfigFleetConfigs | cdktf.IResolvable): any;
export interface GoogleGameServicesGameServerConfigScalingConfigsSchedules {
    /**
    * The duration for the cron job event. The duration of the event is effective
  after the cron job's start time.
  
  A duration in seconds with up to nine fractional digits, terminated by 's'. Example: "3.5s".
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#cron_job_duration GoogleGameServicesGameServerConfig#cron_job_duration}
    */
    readonly cronJobDuration?: string;
    /**
    * The cron definition of the scheduled event. See
  https://en.wikipedia.org/wiki/Cron. Cron spec specifies the local time as
  defined by the realm.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#cron_spec GoogleGameServicesGameServerConfig#cron_spec}
    */
    readonly cronSpec?: string;
    /**
    * The end time of the event.
  
  A timestamp in RFC3339 UTC "Zulu" format, accurate to nanoseconds. Example: "2014-10-02T15:01:23.045123456Z".
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#end_time GoogleGameServicesGameServerConfig#end_time}
    */
    readonly endTime?: string;
    /**
    * The start time of the event.
  
  A timestamp in RFC3339 UTC "Zulu" format, accurate to nanoseconds. Example: "2014-10-02T15:01:23.045123456Z".
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#start_time GoogleGameServicesGameServerConfig#start_time}
    */
    readonly startTime?: string;
}
export declare function googleGameServicesGameServerConfigScalingConfigsSchedulesToTerraform(struct?: GoogleGameServicesGameServerConfigScalingConfigsSchedules | cdktf.IResolvable): any;
export interface GoogleGameServicesGameServerConfigScalingConfigsSelectors {
    /**
    * Set of labels to group by.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#labels GoogleGameServicesGameServerConfig#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
}
export declare function googleGameServicesGameServerConfigScalingConfigsSelectorsToTerraform(struct?: GoogleGameServicesGameServerConfigScalingConfigsSelectors | cdktf.IResolvable): any;
export interface GoogleGameServicesGameServerConfigScalingConfigs {
    /**
    * Fleet autoscaler spec, which is sent to Agones.
  Example spec can be found :
  https://agones.dev/site/docs/reference/fleetautoscaler/
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#fleet_autoscaler_spec GoogleGameServicesGameServerConfig#fleet_autoscaler_spec}
    */
    readonly fleetAutoscalerSpec: string;
    /**
    * The name of the ScalingConfig
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#name GoogleGameServicesGameServerConfig#name}
    */
    readonly name: string;
    /**
    * schedules block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#schedules GoogleGameServicesGameServerConfig#schedules}
    */
    readonly schedules?: GoogleGameServicesGameServerConfigScalingConfigsSchedules[] | cdktf.IResolvable;
    /**
    * selectors block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#selectors GoogleGameServicesGameServerConfig#selectors}
    */
    readonly selectors?: GoogleGameServicesGameServerConfigScalingConfigsSelectors[] | cdktf.IResolvable;
}
export declare function googleGameServicesGameServerConfigScalingConfigsToTerraform(struct?: GoogleGameServicesGameServerConfigScalingConfigs | cdktf.IResolvable): any;
export interface GoogleGameServicesGameServerConfigTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#create GoogleGameServicesGameServerConfig#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config#delete GoogleGameServicesGameServerConfig#delete}
    */
    readonly delete?: string;
}
export declare function googleGameServicesGameServerConfigTimeoutsToTerraform(struct?: GoogleGameServicesGameServerConfigTimeoutsOutputReference | GoogleGameServicesGameServerConfigTimeouts | cdktf.IResolvable): any;
export declare class GoogleGameServicesGameServerConfigTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGameServicesGameServerConfigTimeouts | undefined;
    set internalValue(value: GoogleGameServicesGameServerConfigTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config google_game_services_game_server_config}
*/
export declare class GoogleGameServicesGameServerConfig extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_game_services_game_server_config";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_game_services_game_server_config google_game_services_game_server_config} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleGameServicesGameServerConfigConfig
    */
    constructor(scope: Construct, id: string, config: GoogleGameServicesGameServerConfigConfig);
    private _configId?;
    get configId(): string;
    set configId(value: string);
    get configIdInput(): string | undefined;
    private _deploymentId?;
    get deploymentId(): string;
    set deploymentId(value: string);
    get deploymentIdInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    get id(): string;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _fleetConfigs?;
    get fleetConfigs(): GoogleGameServicesGameServerConfigFleetConfigs[] | cdktf.IResolvable;
    set fleetConfigs(value: GoogleGameServicesGameServerConfigFleetConfigs[] | cdktf.IResolvable);
    get fleetConfigsInput(): cdktf.IResolvable | GoogleGameServicesGameServerConfigFleetConfigs[] | undefined;
    private _scalingConfigs?;
    get scalingConfigs(): GoogleGameServicesGameServerConfigScalingConfigs[] | cdktf.IResolvable;
    set scalingConfigs(value: GoogleGameServicesGameServerConfigScalingConfigs[] | cdktf.IResolvable);
    resetScalingConfigs(): void;
    get scalingConfigsInput(): cdktf.IResolvable | GoogleGameServicesGameServerConfigScalingConfigs[] | undefined;
    private _timeouts;
    get timeouts(): GoogleGameServicesGameServerConfigTimeoutsOutputReference;
    putTimeouts(value: GoogleGameServicesGameServerConfigTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): GoogleGameServicesGameServerConfigTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
